from zetapy.main import getZeta, getIFR
from zetapy.msd import getMultiScaleDeriv
from zetapy.dependencies import getPeak, getGumbel, getOnset, getTempOffset, flatten, calculatePeths

"""
Main function to calculate ZETA: zetapy.getZeta
Read me and how-to-use example: https://github.com/JorritMontijn/zetapy/
"""

__version__ = '2.7'
__author__ = 'Jorrit Montijn, Guido Meijer & Alexander Heimel'